/*
 * Copyright (C) 2013 Sergej Shafarenka, halfbit.de
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hb.examples;

import java.util.ArrayList;
import java.util.List;

import android.app.ListActivity;
import android.content.Context;
import android.graphics.Color;
import android.os.Bundle;
import android.view.Menu;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import com.hb.examples.pinnedsection.R;
import com.hb.views.PinnedSectionListView.PinnedSectionListAdapter;

public class PinnedSectionListActivity extends ListActivity implements OnClickListener {

    private static final int[] COLORS = new int[] {
        R.color.green_light, R.color.orange_light,
        R.color.blue_light, R.color.red_light };

	private class MyPinnedSectionListAdapter extends ArrayAdapter<Item> implements PinnedSectionListAdapter {

		public MyPinnedSectionListAdapter(Context context, int resource, int textViewResourceId, List<Item> objects) {
			super(context, resource, textViewResourceId, objects);
		}

		@Override public View getView(int position, View convertView, ViewGroup parent) {
			TextView view = (TextView) super.getView(position, convertView, parent);
			view.setTextColor(Color.DKGRAY);
			view.setTag("" + position);
			if (getItem(position).type == Item.SECTION) {
			    //view.setOnClickListener(PinnedSectionListActivity.this);
				view.setBackgroundColor(parent.getResources().getColor(COLORS[position % COLORS.length]));
			}
			return view;
		}

		@Override public int getViewTypeCount() {
			return 2;
		}

		@Override public int getItemViewType(int position) {
			return getItem(position).type;
		}

		@Override public boolean isItemViewTypePinned(int viewType) {
			return viewType == Item.SECTION;
		}
	}

	private static class Item {
		public static final int ITEM = 0;
		public static final int SECTION = 1;

		public final int type;
		public final String text;

		public Item(int type, String text) {
			this.type = type;
			this.text = text;
		}

		@Override public String toString() {
			return text;
		}
	}

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		MyPinnedSectionListAdapter adapter = new MyPinnedSectionListAdapter(
				this, android.R.layout.simple_list_item_1, android.R.id.text1, prepareItems());
		setListAdapter(adapter);
	}

	@Override
	protected void onListItemClick(ListView l, View v, int position, long id) {
	    Toast.makeText(this, "Item: " + position, Toast.LENGTH_SHORT).show();
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

	private static ArrayList<Item> prepareItems() {
		ArrayList<Item> result = new ArrayList<Item>();
		for (int i = 0; i < 30; i++) {
			result.add(new Item(Item.SECTION, "Section " + i));
			for (int j=0; j<4; j++) {
				result.add(new Item(Item.ITEM, "Item " + j));
			}
		}
		return result;
	}

    @Override
    public void onClick(View v) {
        Toast.makeText(this, "Item: " + v.getTag(), Toast.LENGTH_SHORT).show();
    }

}
